@@ -19,32 +19,18 @@
 #elif defined(GDCM_BUILD_TESTING)
 #include "gdcm_md5.h"
 #endif
+#include <fstream>
+#include <vector>
+#include <stdio.h>
+#if defined(_MSC_VER) && (_MSC_VER < 1900)
+#define snprintf _snprintf
+#endif
 
-#include <string.h>//memcmp
-#include <stdlib.h> // malloc
-#include <stdio.h> // fopen
-
-/*
- */
+// http://stackoverflow.com/questions/13256446/compute-md5-hash-value-by-c-winapi
 namespace gdcm
 {
 
-class MD5Internals
-{
-public:
-};
-
-MD5::MD5()
-{
-  Internals = new MD5Internals;
-}
-
-MD5::~MD5()
-{
-  delete Internals;
-}
-
-bool MD5::Compute(const char *buffer, unsigned long buf_len, char digest_str[33])
+bool MD5::Compute(const char *buffer, size_t buf_len, char digest_str[33])
 {
   if( !buffer || !buf_len )
     {
@@ -56,97 +42,70 @@ bool MD5::Compute(const char *buffer, unsigned long buf_len, char digest_str[33]
   MD5_Init(&ctx);
   MD5_Update(&ctx, buffer, buf_len);
   MD5_Final(digest, &ctx);
+  for (int di = 0; di < 16; ++di)
+    snprintf(digest_str+2*di, 3, "%02x", digest[di]);
+  digest_str[2*16] = '\0';
+  return true;
 #elif defined(GDCM_BUILD_TESTING)
   md5_byte_t digest[16];
   md5_state_t state;
   md5_init(&state);
   md5_append(&state, (const md5_byte_t *)buffer, buf_len);
   md5_finish(&state, digest);
-#else
-  unsigned char digest[16] = {};
-  return false;
-#endif
   for (int di = 0; di < 16; ++di)
-    {
-    sprintf(digest_str+2*di, "%02x", digest[di]);
-    }
+    snprintf(digest_str+2*di, 3, "%02x", digest[di]);
   digest_str[2*16] = '\0';
   return true;
+#else
+  (void)digest_str;
+  return false;
+#endif
 }
 
 #ifdef GDCM_USE_SYSTEM_OPENSSL
-inline bool process_file(const char *filename, unsigned char *digest)
+static bool process_file(const char *filename, unsigned char *digest)
 {
   if( !filename || !digest ) return false;
 
-  FILE *file = fopen(filename, "rb");
-  if(!file)
-    {
-    return false;
-    }
+  std::ifstream file(filename, std::ios::binary);
+  if(!file) return false;
 
-  size_t file_size = System::FileSize(filename);
-  void *buffer = malloc(file_size);
-  if(!buffer)
-    {
-    fclose(file);
-    return false;
-    }
-  size_t read = fread(buffer, 1, file_size, file);
-  if( read != file_size ) return false;
+  const size_t file_size = System::FileSize(filename);
+  std::vector<char> v( file_size );
+
+  char *buffer = &v[0];
+  file.read(buffer, file_size);
 
   MD5_CTX ctx;
   MD5_Init(&ctx);
   MD5_Update(&ctx, buffer, file_size);
   MD5_Final(digest, &ctx);
 
-  /*printf("MD5 (\"%s\") = ", test[i]); */
-  /*for (int di = 0; di < 16; ++di)
-  {
-    printf("%02x", digest[di]);
-  }*/
-  //printf("\t%s\n", filename);
-  free(buffer);
-  fclose(file);
   return true;
 }
 #elif defined(GDCM_BUILD_TESTING)
-inline bool process_file(const char *filename, md5_byte_t *digest)
+static bool process_file(const char *filename, md5_byte_t *digest)
 {
   if( !filename || !digest ) return false;
 
-  FILE *file = fopen(filename, "rb");
-  if(!file)
-    {
-    return false;
-    }
+  std::ifstream file(filename, std::ios::binary);
+  if(!file) return false;
 
-  size_t file_size = System::FileSize(filename);
-  void *buffer = malloc(file_size);
-  if(!buffer)
-    {
-    fclose(file);
-    return false;
-    }
-  size_t read = fread(buffer, 1, file_size, file);
-  if( read != file_size ) return false;
+  const size_t file_size = System::FileSize(filename);
+  std::vector<char> v( file_size );
+
+  char *buffer = &v[0];
+  file.read(buffer, file_size);
 
   md5_state_t state;
   md5_init(&state);
   md5_append(&state, (const md5_byte_t *)buffer, file_size);
   md5_finish(&state, digest);
-  /*printf("MD5 (\"%s\") = ", test[i]); */
-  /*for (int di = 0; di < 16; ++di)
-  {
-    printf("%02x", digest[di]);
-  }*/
-  //printf("\t%s\n", filename);
-  free(buffer);
-  fclose(file);
+
   return true;
 }
 #else
-inline bool process_file(const char *, unsigned char *)
+static inline bool process_file(const char *, unsigned char *)
 {
   return false;
 }
@@ -154,8 +113,6 @@ inline bool process_file(const char *, unsigned char *)
 
 bool MD5::ComputeFile(const char *filename, char digest_str[33])
 {
-  // If not file exist
-  // return false;
 #ifdef GDCM_USE_SYSTEM_OPENSSL
   unsigned char digest[16];
 #elif defined(GDCM_BUILD_TESTING)
@@ -171,7 +128,7 @@ bool MD5::ComputeFile(const char *filename, char digest_str[33])
 
   for (int di = 0; di < 16; ++di)
     {
-    sprintf(digest_str+2*di, "%02x", digest[di]);
+    snprintf(digest_str+2*di, 3, "%02x", digest[di]);
     }
   digest_str[2*16] = '\0';
   return true;
