@@ -24,7 +24,7 @@
 
 #include "gdcmTag.h"
 
-namespace gdcm
+namespace gdcm_ns
 {
 
 const char FileMetaInformation::GDCM_FILE_META_INFORMATION_VERSION[] = "\0\1";
@@ -54,33 +54,51 @@ const char * FileMetaInformation::GetGDCMSourceApplicationEntityTitle()
   return GDCM_SOURCE_APPLICATION_ENTITY_TITLE;
 }
 
+// Keep cstor and dstor here to keep API minimal (see dllexport issue with gdcmstrict::)
+FileMetaInformation::FileMetaInformation():DataSetTS(TransferSyntax::TS_END),MetaInformationTS(TransferSyntax::Unknown),DataSetMS(MediaStorage::MS_END) {}
+FileMetaInformation::~FileMetaInformation() = default;
+
 void FileMetaInformation::SetImplementationClassUID(const char * imp)
 {
-  assert(0);
-  (void)imp;
+  // TODO: it would be nice to make sure imp is actually a valid UID
+  if( imp )
+    {
+    ImplementationClassUID = imp;
+    }
 }
 
 void FileMetaInformation::AppendImplementationClassUID(const char * imp)
 {
-  ImplementationClassUID = GetGDCMImplementationClassUID();
-  ImplementationClassUID += ".";
-  ImplementationClassUID += imp;
+  if( imp )
+    {
+    std::string tmp = GetGDCMImplementationClassUID();
+    tmp += ".";
+    tmp += imp;
+    if( tmp.size() <= 64 ) { ImplementationClassUID = tmp; }
+    }
 }
+
 void FileMetaInformation::SetImplementationVersionName(const char * version)
 {
-  // Simply override the value since we cannot have more than 16bytes...
-  assert( strlen(version) <= 16 );
-  //ImplementationVersionName = GetGDCMImplementationVersionName();
-  //ImplementationVersionName += "-";
-  //ImplementationVersionName += version;
-  ImplementationVersionName = version;
+  if( version )
+    {
+    // Simply override the value since we cannot have more than 16bytes...
+    gdcmAssertAlwaysMacro( strlen(version) <= 16 );
+    //ImplementationVersionName = GetGDCMImplementationVersionName();
+    //ImplementationVersionName += "-";
+    //ImplementationVersionName += version;
+    ImplementationVersionName = version;
+    }
 }
 void FileMetaInformation::SetSourceApplicationEntityTitle(const char * title)
 {
-  //SourceApplicationEntityTitle = GetGDCMSourceApplicationEntityTitle();
-  //SourceApplicationEntityTitle += "/";
-  AEComp ae( title );
-  SourceApplicationEntityTitle = ae.Truncate();
+  if( title )
+    {
+    //SourceApplicationEntityTitle = GetGDCMSourceApplicationEntityTitle();
+    //SourceApplicationEntityTitle += "/";
+    AEComp ae( title );
+    SourceApplicationEntityTitle = ae.Truncate();
+    }
 }
 const char *FileMetaInformation::GetImplementationClassUID()
 {
@@ -127,7 +145,7 @@ void FileMetaInformation::FillFromDataSet(DataSet const &ds)
     {
     if( !ds.FindDataElement( Tag(0x0008, 0x0016) ) || ds.GetDataElement( Tag(0x0008,0x0016) ).IsEmpty()  )
       {
-      gdcm::MediaStorage ms;
+      MediaStorage ms;
       ms.SetFromModality(ds);
       const char *msstr = ms.GetString();
       if( msstr )
@@ -270,7 +288,7 @@ void FileMetaInformation::FillFromDataSet(DataSet const &ds)
     {
     // Very bad !!
     //throw Exception( "No (0002,0010) element found" );
-    // Constuct it from DataSetTS
+    // Construct it from DataSetTS
     if( DataSetTS == TransferSyntax::TS_END )
       {
       throw gdcm::Exception( "No TransferSyntax specified." );
@@ -341,7 +359,7 @@ void FileMetaInformation::FillFromDataSet(DataSet const &ds)
 }
 
 // FIXME
-// This code should clearly be rewritten with some template meta programing to
+// This code should clearly be rewritten with some template meta-programming to
 // enable reuse of code...
 //
 // \postcondition after the file meta information (well before the dataset...)
@@ -360,7 +378,7 @@ bool ReadExplicitDataElement(std::istream &is, ExplicitDataElement &de)
   //std::cout << "Tag: " << t << std::endl;
   if( t.GetGroup() != 0x0002 )
     {
-    gdcmDebugMacro( "Done reading File Meta Information" );
+    //gdcmDebugMacro( "Done reading File Meta Information" );
     std::streampos currentpos = is.tellg();
     // old code was fseeking from the beginning of file
     // which seems to be quite different than fseeking in reverse from
@@ -396,7 +414,7 @@ bool ReadExplicitDataElement(std::istream &is, ExplicitDataElement &de)
     }
   //gdcmDebugMacro( "VL : " << vl );
   // Read the Value
-  ByteValue *bv = NULL;
+  ByteValue *bv = nullptr;
   if( vr == VR::SQ )
     {
     assert(0 && "Should not happen");
@@ -463,7 +481,7 @@ bool ReadImplicitDataElement(std::istream &is, ImplicitDataElement &de)
     assert(0 && "Should not happen");
     return false;
     }
-  ByteValue *bv = 0;
+  ByteValue *bv = nullptr;
   if( vl.IsUndefined() )
     {
     assert(0 && "Should not happen");
@@ -509,6 +527,7 @@ std::istream &FileMetaInformation::Read(std::istream &is)
   //ExplicitAttribute<0x0002,0x0000> metagl;
   //metagl.Read(is);
 
+  std::streampos start = is.tellg();
   // TODO: Can now load data from std::ios::cur to std::ios::cur + metagl.GetValue()
 
   ExplicitDataElement xde;
@@ -528,10 +547,36 @@ std::istream &FileMetaInformation::Read(std::istream &is)
 //#endif
   Insert( xde );
   // See PS 3.5, Data Element Structure With Explicit VR
+  try {
+  // GDCM is a hack, so let's read all possible group 2 element, until the last one
+  // and leave the group length value aside.
   while( ReadExplicitDataElement<SwapperNoOp>(is, xde ) )
     {
     Insert( xde );
     }
+  }
+  catch( std::exception & ex )
+  {
+(void)ex;
+    // we've read a little bit too much. We are possibly in the case where an
+    // implicit dataelement with group 2 (technically impossible) was found
+    // (first dataelement). Let's start over again, but this time use group
+    // length as the sentinel for the last group 2 element:
+  is.seekg(start,std::ios::beg);
+  // Group Length:
+  ReadExplicitDataElement<SwapperNoOp>(is, xde );
+
+  Attribute<0x0002, 0x0000> filemetagrouplength;
+  filemetagrouplength.SetFromDataElement( xde );
+  const unsigned int glen = filemetagrouplength.GetValue();
+
+  unsigned int cur_len = 0;
+    while( cur_len < glen && ReadExplicitDataElement<SwapperNoOp>(is, xde ) )
+   {
+    Insert( xde );
+    cur_len += xde.GetLength();
+    }
+  }
 
   // Now is a good time to compute the transfer syntax:
   ComputeDataSetTransferSyntax();
@@ -554,7 +599,6 @@ std::istream &FileMetaInformation::ReadCompat(std::istream &is)
   if( !t.Read<SwapperNoOp>(is) )
     {
     throw Exception( "Cannot read very first tag" );
-    return is;
     }
   if( t.GetGroup() == 0x0002 )
     {
@@ -599,8 +643,19 @@ std::istream &FileMetaInformation::ReadCompat(std::istream &is)
     }
   else if( t.GetElement() == 0x0010 ) // Hum, is it a private creator ?
     {
-    is.seekg(-4, std::ios::cur); // Seek back
-    DataSetTS = TransferSyntax::ImplicitVRLittleEndian;
+    char vr_str[3];
+    is.read(vr_str, 2);
+    vr_str[2] = '\0';
+    VR::VRType vr = VR::GetVRType(vr_str);
+    if( vr != VR::VR_END )
+      {
+      DataSetTS = TransferSyntax::ExplicitVRLittleEndian;
+      }
+    else
+      {
+      DataSetTS = TransferSyntax::ImplicitVRLittleEndian;
+      }
+    is.seekg(-6, std::ios::cur); // Seek back
     }
   else
     {
@@ -650,7 +705,7 @@ std::istream &FileMetaInformation::ReadCompat(std::istream &is)
 #define ADDVRIMPLICIT( element ) \
     case element: \
       de.SetVR( (VR::VRType)TagToType<0x0002,element>::VRType ); \
-      break;
+      break
 
 bool AddVRToDataElement(DataElement &de)
 {
@@ -679,9 +734,9 @@ std::istream &FileMetaInformation::ReadCompatInternal(std::istream &is)
 //  if( t.GetGroup() == 0x0002 )
     {
     // Purposely not Re-use ReadVR since we can read VR_END
-    char vr_str[2];
-    is.read(vr_str, 2);
-    if( VR::IsValid(vr_str) )
+    char vr_str0[2];
+    is.read(vr_str0, 2);
+    if( VR::IsValid(vr_str0) )
       {
       MetaInformationTS = TransferSyntax::Explicit;
       // Hourah !
@@ -707,7 +762,7 @@ std::istream &FileMetaInformation::ReadCompatInternal(std::istream &is)
     else
       {
       MetaInformationTS = TransferSyntax::Implicit;
-      gdcmWarningMacro( "File Meta Information is implicit. VR will be explicitely added" );
+      gdcmWarningMacro( "File Meta Information is implicit. VR will be explicitly added" );
       // Ok this might be an implicit encoded Meta File Information header...
       // GE_DLX-8-MONO2-PrivateSyntax.dcm
       is.seekg(-6, std::ios::cur); // Seek back
@@ -724,7 +779,34 @@ std::istream &FileMetaInformation::ReadCompatInternal(std::istream &is)
           }
         }
       // Now is a good time to find out the dataset transfer syntax
+      try {
       ComputeDataSetTransferSyntax();
+      } catch( gdcm::Exception & ) {
+        // We were able to read some of the Meta Header, but failed to compute the DataSetTS
+        // technically GDCM is able to cope with any value here. But be kind and try to have a good guess:
+     
+          gdcmWarningMacro( "Meta Header is bogus. Guessing DataSet TS." );
+  Tag t;
+  if( !t.Read<SwapperNoOp>(is) )
+    {
+    throw Exception( "Cannot read very first tag" );
+    }
+
+    char vr_str[3];
+    is.read(vr_str, 2);
+    vr_str[2] = '\0';
+    VR::VRType vr = VR::GetVRType(vr_str);
+    if( vr != VR::VR_END )
+      {
+      DataSetTS = TransferSyntax::ExplicitVRLittleEndian;
+      }
+    else
+      {
+      DataSetTS = TransferSyntax::ImplicitVRLittleEndian;
+      }
+    is.seekg(-6, std::ios::cur); // Seek back
+
+      }
       }
     }
 //  else
@@ -757,7 +839,6 @@ void FileMetaInformation::ComputeDataSetTransferSyntax()
     }
   // Pad string with a \0
   ts = std::string(bv->GetPointer(), bv->GetLength());
-  gdcmDebugMacro( "TS: " << ts.c_str() );
   TransferSyntax tst(TransferSyntax::GetTSType(ts.c_str()));
   if( tst == TransferSyntax::TS_END )
     {
@@ -774,7 +855,7 @@ void FileMetaInformation::SetDataSetTransferSyntax(const TransferSyntax &ts)
   DataSetTS = ts;
 }
 
-MediaStorage FileMetaInformation::GetMediaStorage() const
+std::string FileMetaInformation::GetMediaStorageAsString() const
 {
   // D 0002|0002 [UI] [Media Storage SOP Class UID]
   // [1.2.840.10008.5.1.4.1.1.12.1]
@@ -784,7 +865,7 @@ MediaStorage FileMetaInformation::GetMediaStorage() const
     {
     gdcmDebugMacro( "File Meta information is present but does not"
       " contains " << t );
-    return MediaStorage::MS_END;
+    return "";
     }
   const DataElement &de = GetDataElement(t);
   std::string ts;
@@ -798,7 +879,7 @@ MediaStorage FileMetaInformation::GetMediaStorage() const
       }
     }
   // Paranoid check: if last character of a VR=UI is space let's pretend this is a \0
-  if( ts.size() )
+  if( !ts.empty() )
     {
     char &last = ts[ts.size()-1];
     if( last == ' ' )
@@ -807,11 +888,18 @@ MediaStorage FileMetaInformation::GetMediaStorage() const
       last = '\0';
       }
     }
-  gdcmDebugMacro( "TS: " << ts );
+  return ts;
+}
+
+MediaStorage FileMetaInformation::GetMediaStorage() const
+{
+  const std::string &ts = GetMediaStorageAsString();
+  if( ts.empty() ) return MediaStorage::MS_END;
+
   MediaStorage ms = MediaStorage::GetMSType(ts.c_str());
   if( ms == MediaStorage::MS_END )
     {
-    gdcmWarningMacro( "Media Storage Class UID: " << ts << " is unknow" );
+    gdcmWarningMacro( "Media Storage Class UID: " << ts << " is unknown" );
     }
   return ms;
 }
@@ -871,4 +959,4 @@ std::ostream &FileMetaInformation::Write(std::ostream &os) const
   return os;
 }
 
-} // end namespace gdcm
+} // end namespace gdcm_ns
