@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -24,17 +23,32 @@ struct dummy
 
 template<int,int> struct TagToElement;
 template<> struct TagToElement<0x0018,0x1624> {
-  typedef gdcm::Element<gdcm::VR::US,gdcm::VM::VM3> Type;
+  using Type = gdcm::Element<gdcm::VR::US, gdcm::VM::VM3>;
 };
 
 int TestElement2(int, char *[])
 {
-  gdcm::Element<gdcm::VR::US, gdcm::VM::VM3> ref = {0,1,2};
-  dummy d = {0,1,2};
+  gdcm::Element<gdcm::VR::US, gdcm::VM::VM3> ref = {{0,1,2}};
+  ref.Print(std::cout);
+  //dummy d = {{0,1,2}};//commenting out
 
-  TagToElement<0x0018,0x1624>::Type t = {1,2,3};
+  TagToElement<0x0018,0x1624>::Type t = {{1,2,3}};
   t.Print( std::cout );
   std::cout << std::endl;
 
+  gdcm::Element<gdcm::VR::US, gdcm::VM::VM1_2> ref2; // = {{1}};
+  ref2.SetLength(2);
+  ref2.SetValue(1);
+  ref2.Print(std::cout);
+  std::cout << std::endl;
+
+  gdcm::Element<gdcm::VR::US, gdcm::VM::VM3_4> ref3; // = {{1}};
+  ref3.SetLength(4);
+  ref3.SetValue(1,0);
+  ref3.SetValue(2,1);
+  ref3.Print(std::cout);
+  std::cout << std::endl;
+
+
   return 0;
 }
