@@ -25,18 +25,18 @@
 #include "gdcmQueryFactory.h"
 #include "gdcmGlobal.h"
 
-const char *AETitle = "ANY";
-const char *PeerAETitle = "ANY";
-const char *ComputerName = "87.106.65.167"; // www.dicomserver.co.uk
-int port = 11112;
+static const char AETitle[] = "ANY";
+static const char PeerAETitle[] = "ANY";
+static const char ComputerName[] = "51.75.171.41"; // www.dicomserver.co.uk
+static int port = 11112;
 
-gdcm::network::ULConnectionManager *GetConnectionManager(gdcm::BaseRootQuery* theQuery)
+static gdcm::network::ULConnectionManager *GetConnectionManager(gdcm::BaseRootQuery* theQuery)
 {
   gdcm::PresentationContextGenerator generator;
   if( !generator.GenerateFromUID( theQuery->GetAbstractSyntaxUID() ) )
     {
-    gdcmErrorMacro( "Failed to generate pres context." );
-    return NULL;
+    gdcmErrorMacro( "Failed to generate pres. context." );
+    return nullptr;
     }
 
   gdcm::network::ULConnectionManager *theManager =
@@ -49,7 +49,8 @@ gdcm::network::ULConnectionManager *GetConnectionManager(gdcm::BaseRootQuery* th
   return theManager;
 }
 
-std::vector<gdcm::DataSet> GetPatientInfo(bool validateQuery, bool inStrictQuery)
+#if 0
+static std::vector<gdcm::DataSet> GetPatientInfo(bool validateQuery, bool inStrictQuery)
 {
   std::vector<gdcm::DataSet> theDataSets;
   gdcm::BaseRootQuery* theQuery =
@@ -67,8 +68,9 @@ std::vector<gdcm::DataSet> GetPatientInfo(bool validateQuery, bool inStrictQuery
   theDataSets  = theManager->SendFind( theQuery );
   return theDataSets;
 }
+#endif
 
-std::vector<gdcm::DataSet> GetStudyInfo(const char *patientID, bool validateQuery, bool inStrictQuery)
+static std::vector<gdcm::DataSet> GetStudyInfo(const char *patientID, bool validateQuery, bool inStrictQuery)
 {
   std::vector<gdcm::DataSet> theDataSets;
   gdcm::BaseRootQuery* theQuery =
@@ -89,7 +91,7 @@ std::vector<gdcm::DataSet> GetStudyInfo(const char *patientID, bool validateQuer
   return theDataSets;
 }
 
-std::vector<gdcm::DataSet> GetSeriesInfo(const char *patientID, const char *studyInstanceUID, bool validateQuery, bool inStrictQuery)
+static std::vector<gdcm::DataSet> GetSeriesInfo(const char *patientID, const char *studyInstanceUID, bool validateQuery, bool inStrictQuery)
 {
   std::vector<gdcm::DataSet> theDataSets;
   gdcm::BaseRootQuery* theQuery =
@@ -108,12 +110,12 @@ std::vector<gdcm::DataSet> GetSeriesInfo(const char *patientID, const char *stud
   return theDataSets;
 }
 
-std::vector<gdcm::DataSet> GetImageInfo(const char *patientID,
+static std::vector<gdcm::DataSet> GetImageInfo(const char *patientID,
                const char *studyInstanceUID, const char *seriesInstanceUID, bool validateQuery, bool inStrictQuery)
 {
   std::vector<gdcm::DataSet> theDataSets;
   gdcm::BaseRootQuery* theQuery =
-    gdcm::QueryFactory::ProduceQuery(gdcm::eStudyRootType, gdcm::eFind, gdcm::eImageOrFrame);
+    gdcm::QueryFactory::ProduceQuery(gdcm::eStudyRootType, gdcm::eFind, gdcm::eImage);
   theQuery->SetSearchParameter(gdcm::Tag(0x8, 0x52), "SERIES"); //Query/Retrieval Level
 
   theQuery->SetSearchParameter(gdcm::Tag(0x10,0x20), patientID); //Patient ID
@@ -129,7 +131,7 @@ std::vector<gdcm::DataSet> GetImageInfo(const char *patientID,
   return theDataSets;
 }
 
-void PrintDataSets(std::vector<gdcm::DataSet> theDataSets)
+static void PrintDataSets(std::vector<gdcm::DataSet> theDataSets)
 {
   std::vector<gdcm::DataSet>::iterator itor;
   for (itor = theDataSets.begin(); itor < theDataSets.end(); itor++)
@@ -139,18 +141,20 @@ void PrintDataSets(std::vector<gdcm::DataSet> theDataSets)
 
 int TestSCUValidation(int , char *[])
 {
+  try
+  {
   //set this to true to use a strict interpretation of the DICOM standard for query validation
   bool theUseStrictQueries = false;
 
   //Case 1:
   //Here I want to retrieve Study Information for the known Patient.
-  //Here i pass the PatientID as a input and i need to reterive the StudyId,
+  //Here I pass the PatientID as a input and I need to reterive the StudyId,
   //StudyDate and Series Instance UID.
   std::vector<gdcm::DataSet> theDataSets = GetStudyInfo("Z354998", true, theUseStrictQueries);
   PrintDataSets(theDataSets);
-  //In the above i validated the constructed Query. This will not allow to add the
+  //In the above I validated the constructed Query. This will not allow to add the
   //Series Instance UID as a search parameter for the query. On the result of
-  //this i can't get the SeriesInstanceUID from the study level.
+  //this I can't get the SeriesInstanceUID from the study level.
 
   //Case 2:
   //Here I execute the above same CFind Query with out validating.
@@ -161,9 +165,9 @@ int TestSCUValidation(int , char *[])
   PrintDataSets(theDataSets);
 
   //case 3:
-  //If i validated the Query Like case 1, i cant get the Series Instance UID from
-  //Study level. With out SeriesInstanceUID i can't retrieve the other series Information.
-  //In Series Level also i cant add the StudyInstanceUID or other study information
+  //If I validated the Query Like case 1, I can't get the Series Instance UID from
+  //Study level. With out SeriesInstanceUID I can't retrieve the other series Information.
+  //In Series Level also I can't add the StudyInstanceUID or other study information
   //as a search parameter. It allows only SeriesInstanceUID, Modality and SeriesNumber
   //as a search parameter.
   theDataSets = GetSeriesInfo("Z354998",
@@ -171,14 +175,14 @@ int TestSCUValidation(int , char *[])
   PrintDataSets(theDataSets);
 
   //case 4:
-  //If i execute the above same CFind Query for Get Series with out validating
+  //If I execute the above same CFind Query for Get Series with out validating
   //the query, it will return the requested SeriesInstanceUID for Known Study level.
   theDataSets = GetSeriesInfo("Z354998",
     "1.2.826.0.1.3680043.4.1.19990124221049.2", false, theUseStrictQueries);
   PrintDataSets(theDataSets);
-  //In StudyLevel I cant get the Series information(Ref:Case 2). In Series Level
-  //also i cant get the Series information for the known Study Level(Ref:Case 3).
-  //How should i get the Series level information for the known patient and study
+  //In StudyLevel I can't get the Series information(Ref:Case 2). In Series Level
+  //also I can't get the Series information for the known Study Level(Ref:Case 3).
+  //How should I get the Series level information for the known patient and study
   //level information???
 
   //case 5:
@@ -198,6 +202,11 @@ int TestSCUValidation(int , char *[])
     "1.2.826.0.1.3680043.4.1.19990124221049.2",
     "1.2.826.0.1.3680043.4.1.19990124221049.3", false, theUseStrictQueries);
   PrintDataSets(theDataSets);
+  }
+  catch( std::exception & )
+  {
+    return 1;
+  }
 
   //I want the Following things to do in CFind Query.
   // 1. Reterive the Study Level Information for the known Patient.
